@@ -30,8 +30,8 @@
 
 using namespace LxImage;
 
-static const char* serviceName = "org.lxde.LxImage";
-static const char* ifaceName = "org.lxde.LxImage.Application";
+static const char* serviceName = "org.lxqt.LxImage";
+static const char* ifaceName = "org.lxqt.LxImage.Application";
 
 Application::Application(int& argc, char** argv):
   QApplication(argc, argv),
@@ -89,6 +89,12 @@ bool Application::parseCommandLineArgs() {
   parser.addHelpOption();
   parser.addVersionOption();
 
+  QCommandLineOption fullscreenOption(
+    QStringList() << QStringLiteral("f") << QStringLiteral("fullscreen"),
+    tr("Start in fullscreen (can be useful with tiling window managers)")
+  );
+  parser.addOption(fullscreenOption);
+
   const bool isX11 = QX11Info::isPlatformX11();
 
   QCommandLineOption screenshotOption(
@@ -141,7 +147,7 @@ bool Application::parseCommandLineArgs() {
       screenshot();
     }
     else
-        newWindow(paths);
+      newWindow(paths, parser.isSet(fullscreenOption));
   }
   else {
     // we're not the primary instance.
@@ -151,62 +157,32 @@ bool Application::parseCommandLineArgs() {
     if(screenshotTool)
       iface.call(QStringLiteral("screenshot"));
     else
-      iface.call(QStringLiteral("newWindow"), paths);
+      iface.call(QStringLiteral("newWindow"), paths, parser.isSet(fullscreenOption));
   }
   return keepRunning;
 }
 
-MainWindow* Application::createWindow() {
+MainWindow* Application::createWindow(bool fullscreen) {
   LxImage::MainWindow* window;
   window = new LxImage::MainWindow();
-
-  // get default shortcuts from the first window
-  if(defaultShortcuts_.isEmpty()) {
-    const auto actions = window->findChildren<QAction*>();
-    for(const auto& action : actions) {
-      if(action->objectName().isEmpty() || action->text().isEmpty()) {
-        continue;
-      }
-      QKeySequence seq = action->shortcut();
-      ShortcutDescription s;
-      s.displayText = action->text().remove(QLatin1Char('&')); // without mnemonics
-      s.shortcut = seq;
-      defaultShortcuts_.insert(action->objectName(), s);
-    }
-  }
-
-  // apply custom shortcuts to this window
-  QHash<QString, QString> ca = settings_.customShortcutActions();
-  const auto actions = window->findChildren<QAction*>();
-  for(const auto& action : actions) {
-    const QString objectName = action->objectName();
-    if(ca.contains(objectName)) {
-      auto shortcut = ca.take(objectName);
-      // custom shortcuts are saved in the PortableText format.
-      action->setShortcut(QKeySequence(shortcut, QKeySequence::PortableText));
-    }
-    if(ca.isEmpty()) {
-      break;
-    }
-  }
-
+  window->setShowFullScreen(fullscreen);
   return window;
 }
 
-void Application::newWindow(QStringList files) {
+void Application::newWindow(QStringList files, bool fullscreen) {
   LxImage::MainWindow* window;
   if(files.empty()) {
-    window = createWindow();
+    window = createWindow(fullscreen);
 
     window->resize(settings_.windowWidth(), settings_.windowHeight());
     if(settings_.windowMaximized())
       window->setWindowState(window->windowState() | Qt::WindowMaximized);
 
-    window->show();
+    window->showAndRaise();
   }
   else {
     for(const QString& fileName : qAsConst(files)) {
-      window = createWindow();
+      window = createWindow(fullscreen);
       window->openImageFile(fileName);
 
       window->resize(settings_.windowWidth(), settings_.windowHeight());
