@@ -43,8 +43,8 @@ public:
   bool init(int argc, char** argv);
   bool parseCommandLineArgs();
 
-  void newWindow(QStringList files = QStringList());
-  MainWindow* createWindow();
+  void newWindow(QStringList files = QStringList(), bool fullscreen = false);
+  MainWindow* createWindow(bool fullscreen = false);
 
   void addWindow() { // call this when you create a new toplevel window
     ++windowCount_;
@@ -65,6 +65,9 @@ public:
   QHash<QString, ShortcutDescription> defaultShortcuts() const {
     return defaultShortcuts_;
   }
+  void setDefaultShortcuts(QHash<QString, ShortcutDescription> shortcuts) {
+    defaultShortcuts_ = shortcuts;
+  }
 
 public Q_SLOTS:
   void editPreferences();
