@@ -83,12 +83,19 @@ PreferencesDialog::PreferencesDialog(QWidget* parent):
   ui.maxRecentFiles->setValue(settings.maxRecentFiles());
   ui.slideShowInterval->setValue(settings.slideShowInterval());
   ui.oulineBox->setChecked(settings.isOutlineShown());
+  ui.menubarBox->setChecked(settings.isMenubarShown());
+  ui.toolbarBox->setChecked(settings.isToolbarShown());
   ui.annotationBox->setChecked(settings.isAnnotationsToolbarShown());
   ui.forceZoomFitBox->setChecked(settings.forceZoomFit());
+  ui.smoothOnZoomBox->setChecked(settings.smoothOnZoom());
+  ui.useTrashBox->setChecked(settings.useTrash());
 
+  ui.exifDataBox->setChecked(settings.showExifData());
   ui.thumbnailBox->setChecked(settings.showThumbnails());
   // the max. thumbnail size spinbox is in MiB
   ui.thumbnailSpin->setValue(qBound(0, settings.maxThumbnailFileSize() / 1024, 1024));
+  initThumbnailSizes(settings);
+  initThumbnailsPositions(settings);
 
   // shortcuts
   initShortcuts();
@@ -142,13 +149,21 @@ void PreferencesDialog::accept() {
   settings.setMaxRecentFiles(ui.maxRecentFiles->value());
   settings.setSlideShowInterval(ui.slideShowInterval->value());
   settings.showOutline(ui.oulineBox->isChecked());
+  settings.showMenubar(ui.menubarBox->isChecked());
+  settings.showToolbar(ui.toolbarBox->isChecked());
   settings.showAnnotationsToolbar(ui.annotationBox->isChecked());
   settings.setForceZoomFit(ui.forceZoomFitBox->isChecked());
+  settings.setSmoothOnZoom(ui.smoothOnZoomBox->isChecked());
+  settings.setUseTrash(ui.useTrashBox->isChecked());
 
+  settings.setShowExifData(ui.exifDataBox->isChecked());
   settings.setShowThumbnails(ui.thumbnailBox->isChecked());
+  settings.setThumbnailsPosition(ui.thumbnailsPositionComboBox->itemData(ui.thumbnailsPositionComboBox->currentIndex()).toInt());
   // the max. thumbnail size spinbox is in MiB
   settings.setMaxThumbnailFileSize(ui.thumbnailSpin->value() * 1024);
+  settings.setThumbnailSize(ui.thumbnailSizeComboBox->itemData(ui.thumbnailSizeComboBox->currentIndex()).toInt());
 
+  updateThumbnails();
   applyNewShortcuts();
   settings.save();
   QDialog::accept();
@@ -176,6 +191,32 @@ static void findIconThemesInDir(QHash<QString, QString>& iconThemes, const QStri
   g_key_file_free(kf);
 }
 
+void PreferencesDialog::initThumbnailSizes(Settings& settings) {
+  int i = 0;
+  for(const auto & size : settings.thumbnailSizes()) {
+    ui.thumbnailSizeComboBox->addItem(QStringLiteral("%1 × %1").arg(size), size);
+    if(settings.thumbnailSize() == size) {
+      ui.thumbnailSizeComboBox->setCurrentIndex(i);
+    }
+    ++i;
+  }
+}
+
+void PreferencesDialog::initThumbnailsPositions(Settings& settings) {
+  ui.thumbnailsPositionComboBox->addItem(tr("Bottom"), Qt::BottomDockWidgetArea);
+  ui.thumbnailsPositionComboBox->addItem(tr("Top"), Qt::TopDockWidgetArea);
+  ui.thumbnailsPositionComboBox->addItem(tr("Left"), Qt::LeftDockWidgetArea);
+
+  Qt::DockWidgetArea pos = settings.thumbnailsPosition();
+  for(int i = 0; i < ui.thumbnailsPositionComboBox->count(); ++i) {
+    if(ui.thumbnailsPositionComboBox->itemData(i).toInt() == pos) {
+      ui.thumbnailsPositionComboBox->setCurrentIndex(i);
+      return;
+    }
+  }
+  ui.thumbnailsPositionComboBox->setCurrentIndex(0);
+}
+
 void PreferencesDialog::initIconThemes(Settings& settings) {
   // check if auto-detection is done (for example, from xsettings)
   if(settings.useFallbackIconTheme()) { // auto-detection failed
@@ -237,7 +278,7 @@ void PreferencesDialog::showWarning(const QString& text, bool temporary) {
           ui.warningLabel->setVisible(!permanentWarning_.isEmpty());
         });
       }
-      warningTimer_->start(2500);
+      warningTimer_->start(5000);
     }
   }
 }
@@ -373,6 +414,15 @@ void PreferencesDialog::restoreDefaultShortcuts() {
   ui.defaultButton->setEnabled(false);
 }
 
+void PreferencesDialog::updateThumbnails() {
+  const auto windows = qApp->topLevelWidgets();
+  for(const auto& window : windows) {
+    if(window->inherits("LxImage::MainWindow")) {
+      static_cast<MainWindow*>(window)->updateThumbnails();
+    }
+  }
+}
+
 void PreferencesDialog::applyNewShortcuts() {
   // remember the modified shortcuts if they are different from the default ones
   Application* app = static_cast<Application*>(qApp);
